%define         libversion 10.6.1

Name:           geant4
Version:        10.06.p01
Release:        6%{?dist}
Summary:        Toolkit for the simulation of the passage of particles through matter for Intel skylake

License:        BSD
URL:            http://geant4.cern.ch/
Source0:        https://geant4-data.web.cern.ch/geant4-data/releases/%{name}.%{version}.tar.gz


%if 0%{?fedora} > 23
BuildRequires:  motif-devel
# Requires:       motif
%else
BuildRequires:  lesstif-devel
# Requires:       lesstif
%endif
BuildRequires:  mesa-libGLU-devel
BuildRequires:  libXmu-devel
BuildRequires:  libXpm-devel
BuildRequires:  libXi-devel
BuildRequires:  xerces-c-devel
BuildRequires:  expat-devel
BuildRequires:  zlib-devel
BuildRequires:  gcc-c++
BuildRequires:  make
BuildRequires:  cmake
BuildRequires:  qt5-qtbase-devel

# Requires:       mesa-libGLU
# Requires:       libXmu
# Requires:       libXpm
# Requires:       libXi
# Requires:       xerces-c
# Requires:       expat
# Requires:       zlib
# Requires:				qt5-qtbase

%description
Geant4 is a toolkit for the simulation of the passage of particles through matter.
Its areas of application include high energy, nuclear and accelerator physics, as
well as studies in medical and space science.

%package devel
Summary:        Development files for %{name}
Requires:       %{name}%{?_isa} = %{version}-%{release}
Recommends:     mesa-libGLU-devel
Recommends:	    libXmu-devel
Recommends:	    libXpm-devel
Recommends:	    libXi-devel
Recommends:	    xerces-c-devel
Recommends:	    expat-devel
Recommends:	    zlib-devel
Recommends:	    qt5-devel
Recommends:	    cmake
Recommends:	    make
%if 0%{?fedora} > 23
Recommends:	    motif-devel
%else
Recommends:	    lesstif-devel
%endif

%description    devel
Development files for %{name}.

%package examples
Summary:        Examples files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    examples
Examples files for %{name}.

%package data
Summary:        Geant4 datasets
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    data
Geant4 datasets.

%prep
%setup -q -n %{name}.%{version}

%build
mkdir -p %{_target_platform}
pushd %{_target_platform}
str='%optflags'
str=${str/-O2/-O3}
str=${str/-mtune=generic/-march=skylake}
CXXFLAGS=${str}' -DNDEBUG -fno-trapping-math -ftree-vectorize -fno-math-errno'
export CXXFLAGS
LDFLAGS='-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now -specs=/usr/lib/rpm/redhat/redhat-hardened-ld'
export LDFLAGS
LT_SYS_LIBRARY_PATH=/usr/lib64:
export LT_SYS_LIBRARY_PATH
cmake    -DCMAKE_C_FLAGS_RELEASE:STRING=-DNDEBUG \
         -DCMAKE_CXX_FLAGS_RELEASE:STRING=-DNDEBUG \
         -DCMAKE_Fortran_FLAGS_RELEASE:STRING=-DNDEBUG \
         -DCMAKE_VERBOSE_MAKEFILE:BOOL=ON \
         -DCMAKE_INSTALL_PREFIX:PATH=/usr \
         -DINCLUDE_INSTALL_DIR:PATH=/usr/include \
         -DLIB_INSTALL_DIR:PATH=/usr/lib64 \
         -DSYSCONF_INSTALL_DIR:PATH=/etc \
         -DSHARE_INSTALL_PREFIX:PATH=/usr/share \
         -DLIB_SUFFIX=64 -DBUILD_SHARED_LIBS:BOOL=ON\
         -DGEANT4_BUILD_MULTITHREADED=ON \
         -DGEANT4_INSTALL_DATA=ON \
         -DGEANT4_USE_GDML=ON \
         -DGEANT4_USE_G3TOG4=ON \
         -DGEANT4_USE_QT=ON \
         -DOpenGL_GL_PREFERENCE=GLVND \
         -DGEANT4_USE_XM=ON \
         -DGEANT4_USE_OPENGL_X11=ON \
         -DGEANT4_USE_INVENTOR=OFF \
         -DGEANT4_USE_RAYTRACER_X11=ON \
         -DGEANT4_USE_SYSTEM_CLHEP=OFF \
         -DGEANT4_USE_SYSTEM_EXPAT=ON \
         -DGEANT4_USE_SYSTEM_ZLIB=ON \
		 -DGEANT4_BUILD_CXXSTD=14	\
         ..
popd

make %{?_smp_mflags} -C %{_target_platform}

%install
rm -rf %{buildroot}

make install/fast DESTDIR=%{buildroot} -C %{_target_platform}

rm -rf %{buildroot}%{_bindir}/geant4.sh %{buildroot}%{_bindir}/geant4.csh

mkdir -p %{buildroot}%{_sysconfdir}/profile.d

cat > %{buildroot}%{_sysconfdir}/profile.d/%{name}-data.sh <<EOF
export G4NEUTRONHPDATA="%{_datadir}/Geant4-%{libversion}/data/G4NDL4.6"
export G4LEDATA="%{_datadir}/Geant4-%{libversion}/data/G4EMLOW7.9.1"
export G4LEVELGAMMADATA="%{_datadir}/Geant4-%{libversion}/data/PhotonEvaporation5.5"
export G4RADIOACTIVEDATA="%{_datadir}/Geant4-%{libversion}/data/RadioactiveDecay5.4"
export G4PARTICLEXSDATA="%{_datadir}/Geant4-%{libversion}/data/G4PARTICLEXS2.1"
export G4PIIDATA="%{_datadir}/Geant4-%{libversion}/data/G4PII1.3"
export G4REALSURFACEDATA="%{_datadir}/Geant4-%{libversion}/data/RealSurface2.1.1"
export G4SAIDXSDATA="%{_datadir}/Geant4-%{libversion}/data/G4SAIDDATA2.0"
export G4ABLADATA="%{_datadir}/Geant4-%{libversion}/data/G4ABLA3.1"
export G4INCLDATA="%{_datadir}/Geant4-%{libversion}/data/G4INCL1.0"
export G4ENSDFSTATEDATA="%{_datadir}/Geant4-%{libversion}/data/G4ENSDFSTATE2.2"
EOF

cat > %{buildroot}%{_sysconfdir}/profile.d/%{name}-data.csh <<EOF
setenv G4NEUTRONHPDATA "%{_datadir}/Geant4-%{libversion}/data/G4NDL4.6"
setenv G4LEDATA "%{_datadir}/Geant4-%{libversion}/data/G4EMLOW7.9.1"
setenv G4LEVELGAMMADATA "%{_datadir}/Geant4-%{libversion}/data/PhotonEvaporation5.5"
setenv G4RADIOACTIVEDATA "%{_datadir}/Geant4-%{libversion}/data/RadioactiveDecay5.4"
setenv G4PARTICLEXSDATA "%{_datadir}/Geant4-%{libversion}/data/G4PARTICLEXS2.1"
setenv G4PIIDATA "%{_datadir}/Geant4-%{libversion}/data/G4PII1.3"
setenv G4REALSURFACEDATA "%{_datadir}/Geant4-%{libversion}/data/RealSurface2.1.1"
setenv G4SAIDXSDATA "%{_datadir}/Geant4-%{libversion}/data/G4SAIDDATA2.0"
setenv G4ABLADATA "%{_datadir}/Geant4-%{libversion}/data/G4ABLA3.1"
setenv G4INCLDATA "%{_datadir}/Geant4-%{libversion}/data/G4INCL1.0"
setenv G4ENSDFSTATEDATA "%{_datadir}/Geant4-%{libversion}/data/G4ENSDFSTATE2.2"
EOF

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc LICENSE ReleaseNotes
%dir %{_datadir}/Geant4-%{libversion}
%{_libdir}/libG*.so

%files devel
%{_bindir}/geant4-config
%{_includedir}/Geant4
%{_libdir}/Geant4-%{libversion}
%{_datadir}/Geant4-%{libversion}
%exclude %{_datadir}/Geant4-%{libversion}/data
%exclude %{_datadir}/Geant4-%{libversion}/examples

%files examples
%{_datadir}/Geant4-%{libversion}/examples

%files data
%{_datadir}/Geant4-%{libversion}/data
%{_sysconfdir}/profile.d/%{name}-data.csh
%{_sysconfdir}/profile.d/%{name}-data.sh

%changelog
* Thu Apr 23 2020 Qiyu Yan <3437889+karuboniru@users.noreply.github.com> - 10.06.p01-4
- Use O3 build 

* Fri Apr 10 2020 Qiyu Yan <3437889+karuboniru@users.noreply.github.com> - 10.06.p01-3
- rebuilt

* Sun Mar 29 2020 Qiyu Yan <3437889+karuboniru@users.noreply.github.com> - 10.06.p01-2
- rebuilt

* Sat Mar 14 2020 Qiyu Yan <3437889+karuboniru@users.noreply.github.com> - 10.06-4
- rebuilt

* Wed Mar 04 2020 Qiyu Yan <3437889+karuboniru@users.noreply.github.com> - 10.06-3
- rebuilt

* Mon Jan 27 2020 Qiyu Yan <3437889+karuboniru@users.noreply.github.com> - 10.06-2
- rebuilt

* Thu Oct 17 2019 Qiyu Yan <yanqy@ihep.ac.cn> - 10.05.p01-3
- Fix Dep

* Thu Oct 17 2019 Qiyu Yan <yanqy@ihep.ac.cn> - 10.05.p01
- geant4.10.05.p01

* Wed Jan  6 2016 Alexey Kurov <nucleo@fedoraproject.org> - 10.01.p02-1
- geant4.10.01.p02

* Wed Jan  6 2016 Alexey Kurov <nucleo@fedoraproject.org> - 10.01-1
- Initial RPM release
